package com.supervision.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.supervision.domain.LivetalkingChatDTO;
import com.supervision.service.LivetalkingService;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

@Slf4j
@Service
@RequiredArgsConstructor
public class LivetalkingServiceImpl implements LivetalkingService {

    @Value("${livetalking.url}")
    private String livetalkingUrl;

    @Value("${livetalking.session.id:0}")
    private int sessionId;

    @Override
    public void chat(LivetalkingChatDTO livetalkingChatDTO) {
        String url = livetalkingUrl + "/human";
        log.info("Sending chat request to: " + url);
        Map<String, Object> param = new HashMap<>();
        param.put("text", livetalkingChatDTO.getQuery());
        param.put("type", "chat");
        param.put("interrupt",false);
        param.put("sessionid", sessionId);

        // 添加额外的参数
        livetalkingChatDTO.setQuery(null);
        param.put("extra", livetalkingChatDTO);
        HttpRequest request = HttpUtil.createPost(url)
                .body(JSONUtil.toJsonStr(param))
                .header("Content-Type", "application/json");
        try (HttpResponse response = request.execute()) {
            String body = response.body();
            log.info("Chat response: {}", body);
        }
    }

    @Override
    public void setVoice(String voiceId, String digitalHumanId) {
        Assert.notEmpty(voiceId, "语音ID不能为空");
        String url = livetalkingUrl + "/set_voice?voiceId=" + voiceId;
        HttpRequest request = HttpUtil.createGet(url);
        try (HttpResponse execute = request.execute()){
            String body = execute.body();
            log.info("设置语音结果: {}", body);
        }
    }
}
